stts = {}
stts["all"] = ["NN", "NE", "ADJA", "ADJD", "CARD", "VMFIN", "VAFIN", "VVFIN", "VAIMP", "VVIMP", "VVINF", "VAINF", "VMINF", "VVIZU", "VVPP", "VMPP", "VAPP", "ART", "PPER", "PRF", "PPOSAT", "PPOSS", "PDAT", "PDS", "PIAT", "PIDAT", "PIS", "PRELAT", "PRELS", "PWAT", "PWS", "PWAV", "PAV", "ADV", "KOUI", "KOUS", "KON", "KOKOM", "APPR", "APPRART", "APPO", "APZR", "PTKZU", "PTKNEG", "PTKVZ", "PTKA", "PTKANT", "ITJ", "TRUNC", "XY", "FM"]
stts["nouns"] = ["NN", "NE"]
stts["adjectives"] = ["ADJA", "ADJD"]
stts["numbers"] = ["CARD"]
stts["verbs"] = ["VMFIN", "VAFIN", "VVFIN", "VAIMP", "VVIMP", "VVINF", "VAINF", "VMINF", "VVIZU", "VVPP", "VMPP", "VAPP"]
stts["articles"] = ["ART"]
stts["pronouns"] = ["PPER", "PRF", "PPOSAT", "PPOSS", "PDAT", "PDS", "PIAT", "PIDAT", "PIS", "PRELAT", "PRELS", "PWAT", "PWS", "PWAV", "PAV"]
stts["adverb"] = ["ADV"]
stts["conjunctions"] = [ "KOUI", "KOUS", "KON", "KOKOM"]
stts["adpositions"] = ["APPR", "APPRART", "APPO", "APZR"]
stts["particle"] = ["PTKZU", "PTKNEG", "PTKVZ", "PTKA", "PTKANT"]
stts["misc"] = ["ITJ", "TRUNC", "XY", "FM"]

sttsColors = {}
sttsColors["NN"] = "#ed1c24"
sttsColors["NE"] = "#8b0000"
sttsColors["ADJA"] = "#cd5c5c"
sttsColors["ADJD"] = "#ccf"
sttsColors["CARD"] = "#89cff0"
sttsColors["VMFIN"] = "#4169e1"
sttsColors["VAFIN"] = "#d6cadd"
sttsColors["VVFIN"] = "#ca2c92"
sttsColors["VAIMP"] = "#d3d3d3"
sttsColors["VVIMP"] = "#b06500"
sttsColors["VVINF"] = "#96c8a2"
sttsColors["VAINF"] = "#c72c48"
sttsColors["VMINF"] = "#fe28a2"
sttsColors["VVIZU"] = "#ffb6c1"
sttsColors["VVPP"] = "#0f4d92"
sttsColors["VMPP"] = "#353839"
sttsColors["VAPP"] = "#062a78"
sttsColors["ART"] = "#555d50"
sttsColors["PPER"] = "#873260"
sttsColors["PRF"] = "#922724"
sttsColors["PPOSAT"] = "#c89"
sttsColors["PPOSS"] = "#f5f5f5"
sttsColors["PDAT"] = "#d9004c"
sttsColors["PDS"] = "#f77fbe"
sttsColors["PIAT"] = "#8f00ff"
sttsColors["PIDAT"] = "#5b92e5"
sttsColors["PIS"] = "#704214"
sttsColors["PRELAT"] = "#0072bb"
sttsColors["PRELS"] = "#78184a"
sttsColors["PWAT"] = "#b03060"
sttsColors["PWS"] = "#0095b6"
sttsColors["PWAV"] = "#ff6"
sttsColors["PAV"] = "#93c572"
sttsColors["ADV"] = "#8b8589"
sttsColors["KOUI"] = "#1034a6"
sttsColors["KOUS"] = "#4b5320"
sttsColors["KON"] = "#fcf75e"
sttsColors["KOKOM"] = "#ca2c92"
sttsColors["APPR"] = "#f6c"
sttsColors["APPRART"] = "#b76e79"
sttsColors["APPO"] = "#bf94e4"
sttsColors["APZR"] = "#bb3385"
sttsColors["PTKZU"] = "#fefe33"
sttsColors["PTKNEG"] = "#987654"
sttsColors["PTKVZ"] = "#32cd32"
sttsColors["PTKA"] = "#4166f5"
sttsColors["PTKANT"] = "#ffc87c"
sttsColors["ITJ"] = "#7df9ff"
sttsColors["TRUNC"] = "#c19a6b"
sttsColors["XY"] = "#ffcba4"
sttsColors["FM"] = "#73c2fb"